@@ -370,7 +370,7 @@ class QuantEngineClient:
             print('open')
             self.open_event.set()
 
-        websocket.enableTrace(False)
+        websocket.enableTrace(True)
         self.ws = websocket.WebSocketApp(self.Url,
                                          on_message=on_message,
                                          on_error=on_error,
